@@ -1,5 +1,4 @@
 """Console script for open_dev."""
-import subprocess
 import textwrap
 import time
 
@@ -12,17 +11,6 @@ from open_dev.src.open_dev_repo import OpenDevRepo
 click.rich_click.USE_MARKDOWN = True
 
 
-def execute(cmd):
-    """Executes a command."""
-    popen = subprocess.Popen(cmd, stdout=subprocess.PIPE, universal_newlines=True)
-    for stdout_line in iter(popen.stdout.readline, ""):
-        yield stdout_line
-    popen.stdout.close()
-    return_code = popen.wait()
-    if return_code:
-        raise subprocess.CalledProcessError(return_code, cmd)
-
-
 def fstr(string):
     """Formatr strings from the interface."""
     return string.split(" ")
@@ -39,6 +27,12 @@ def create():
     click.echo('Hello there')
 
 
+@click.command()
+def sync():
+    """Creates a new repository."""
+    click.echo('Synchronise state so remote and local are aligned')
+
+
 @click.command()
 def info():
     """Retrieves infromation about the current repo."""
@@ -99,17 +93,12 @@ def install():
     """Synchronise dependencies."""
     click.echo(
         """
-    Installing dependencies with deps with
+    Install dependencies with deps with
     ```bash
     pip install -e . --user
     ````
     """
     )
-    cmds = ["pipenv run pip install poetry", "pipenv run poetry install", "pipenv run pip install ."]
-    for i in cmds:
-        cmd = fstr(i)
-        for path in execute(cmd):
-            print(path, end="")
 
 
 click.echo(textwrap.dedent(HEADER))
@@ -122,6 +111,7 @@ def main():
 
 deps.add_command(install)
 repo.add_command(create)
+repo.add_command(sync)
 repo.add_command(info)
 test.add_command(run_all)
 
